Struct tiny_solver::factors::PriorFactor
source · pub struct PriorFactor {
pub v: DVector<f64>,
}Fields
v: DVector<f64>Trait Implementations
sourceimpl Clone for PriorFactor
impl Clone for PriorFactor
sourcefn clone(&self) -> PriorFactor
fn clone(&self) -> PriorFactor
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PriorFactor
impl Debug for PriorFactor
sourceimpl Factor for PriorFactor
impl Factor for PriorFactor
fn residual_func(&self, params: &[DVector<DualDVec64>]) -> DVector<DualDVec64>
sourceimpl HasPyGilRef for PriorFactor
impl HasPyGilRef for PriorFactor
type AsRefTarget = PyCell<PriorFactor>
type AsRefTarget = PyCell<PriorFactor>
Utility type to make Py::as_ref work.
sourceimpl PyClassImpl for PriorFactor
impl PyClassImpl for PriorFactor
sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
type ThreadChecker = SendablePyClass<PriorFactor>
type ThreadChecker = SendablePyClass<PriorFactor>
This handles following two situations: Read more
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
type BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a PriorFactor
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a PriorFactor
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut PriorFactor
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut PriorFactor
sourceimpl PyTypeInfo for PriorFactor
impl PyTypeInfo for PriorFactor
sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
sourcefn type_object(py: Python<'_>) -> &PyType
fn type_object(py: Python<'_>) -> &PyType
👎Deprecated since 0.21.0:
PyTypeInfo::type_object will be replaced by PyTypeInfo::type_object_bound in a future PyO3 versionReturns the safe abstraction over the type object.
sourcefn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
fn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
sourcefn is_type_of(object: &PyAny) -> bool
fn is_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_type_of will be replaced by PyTypeInfo::is_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type or a subclass of this type.sourcefn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.sourcefn is_exact_type_of(object: &PyAny) -> bool
fn is_exact_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_exact_type_of will be replaced by PyTypeInfo::is_exact_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type.impl DerefToPyAny for PriorFactor