pub struct GaussNewtonOptimizer {}Trait Implementations
sourceimpl Clone for GaussNewtonOptimizer
impl Clone for GaussNewtonOptimizer
sourcefn clone(&self) -> GaussNewtonOptimizer
fn clone(&self) -> GaussNewtonOptimizer
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for GaussNewtonOptimizer
impl Debug for GaussNewtonOptimizer
sourceimpl HasPyGilRef for GaussNewtonOptimizer
impl HasPyGilRef for GaussNewtonOptimizer
type AsRefTarget = PyCell<GaussNewtonOptimizer>
type AsRefTarget = PyCell<GaussNewtonOptimizer>
Utility type to make Py::as_ref work.
sourceimpl Optimizer for GaussNewtonOptimizer
impl Optimizer for GaussNewtonOptimizer
fn optimize( &self, problem: &Problem, initial_values: &HashMap<String, DVector<f64>>, optimizer_option: Option<OptimizerOptions> ) -> HashMap<String, DVector<f64>>
fn apply_dx( &self, dx: &DVector<f64>, params: &mut HashMap<String, DVector<f64>>, variable_name_to_col_idx_dict: &HashMap<String, usize> )
sourceimpl PyClass for GaussNewtonOptimizer
impl PyClass for GaussNewtonOptimizer
sourceimpl PyClassImpl for GaussNewtonOptimizer
impl PyClassImpl for GaussNewtonOptimizer
sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
type ThreadChecker = SendablePyClass<GaussNewtonOptimizer>
type ThreadChecker = SendablePyClass<GaussNewtonOptimizer>
This handles following two situations: Read more
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
type BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a GaussNewtonOptimizer
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a GaussNewtonOptimizer
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut GaussNewtonOptimizer
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut GaussNewtonOptimizer
sourceimpl PyTypeInfo for GaussNewtonOptimizer
impl PyTypeInfo for GaussNewtonOptimizer
sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
sourcefn type_object(py: Python<'_>) -> &PyType
fn type_object(py: Python<'_>) -> &PyType
👎Deprecated since 0.21.0:
PyTypeInfo::type_object will be replaced by PyTypeInfo::type_object_bound in a future PyO3 versionReturns the safe abstraction over the type object.
sourcefn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
fn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
sourcefn is_type_of(object: &PyAny) -> bool
fn is_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_type_of will be replaced by PyTypeInfo::is_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type or a subclass of this type.sourcefn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.sourcefn is_exact_type_of(object: &PyAny) -> bool
fn is_exact_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_exact_type_of will be replaced by PyTypeInfo::is_exact_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type.impl DerefToPyAny for GaussNewtonOptimizer