Struct tiny_solver::optimizer::OptimizerOptions
source · pub struct OptimizerOptions {
pub max_iteration: usize,
pub linear_solver_type: LinearSolver,
pub verbosity_level: usize,
pub min_abs_error_decrease_threshold: f64,
pub min_rel_error_decrease_threshold: f64,
pub min_error_threshold: f64,
}Fields
max_iteration: usizelinear_solver_type: LinearSolververbosity_level: usizemin_abs_error_decrease_threshold: f64min_rel_error_decrease_threshold: f64min_error_threshold: f64Trait Implementations
sourceimpl Clone for OptimizerOptions
impl Clone for OptimizerOptions
sourcefn clone(&self) -> OptimizerOptions
fn clone(&self) -> OptimizerOptions
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Default for OptimizerOptions
impl Default for OptimizerOptions
sourceimpl HasPyGilRef for OptimizerOptions
impl HasPyGilRef for OptimizerOptions
type AsRefTarget = PyCell<OptimizerOptions>
type AsRefTarget = PyCell<OptimizerOptions>
Utility type to make Py::as_ref work.
sourceimpl PyClass for OptimizerOptions
impl PyClass for OptimizerOptions
sourceimpl PyClassImpl for OptimizerOptions
impl PyClassImpl for OptimizerOptions
sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
type ThreadChecker = SendablePyClass<OptimizerOptions>
type ThreadChecker = SendablePyClass<OptimizerOptions>
This handles following two situations: Read more
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
type BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a OptimizerOptions
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a OptimizerOptions
sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut OptimizerOptions
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut OptimizerOptions
sourceimpl PyTypeInfo for OptimizerOptions
impl PyTypeInfo for OptimizerOptions
sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
sourcefn type_object(py: Python<'_>) -> &PyType
fn type_object(py: Python<'_>) -> &PyType
👎Deprecated since 0.21.0:
PyTypeInfo::type_object will be replaced by PyTypeInfo::type_object_bound in a future PyO3 versionReturns the safe abstraction over the type object.
sourcefn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
fn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
sourcefn is_type_of(object: &PyAny) -> bool
fn is_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_type_of will be replaced by PyTypeInfo::is_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type or a subclass of this type.sourcefn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.sourcefn is_exact_type_of(object: &PyAny) -> bool
fn is_exact_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_exact_type_of will be replaced by PyTypeInfo::is_exact_type_of_bound in a future PyO3 versionChecks if
object is an instance of this type.impl DerefToPyAny for OptimizerOptions